@@ -2,9 +2,15 @@
 distsamp <- function(formula, data,
     keyfun=c("halfnorm", "exp", "hazard", "uniform"),
     output=c("density", "abund"), unitsOut=c("ha", "kmsq"), starts=NULL,
-    method="BFGS", se = TRUE, ...)
+    method="BFGS", se = TRUE, engine = c("C", "R"),
+    rel.tol=0.001, ...)
 {
+    engine <- match.arg(engine)
     keyfun <- match.arg(keyfun)
+#    if(engine=="C" && !(keyfun %in% c("halfnorm", "exp", "uniform"))) {
+#        engine <- "R"
+#        warning("C engine not available for hazard model, using R instead")
+#    }
     output <- match.arg(output)
     unitsOut <- match.arg(unitsOut)
     db <- data@dist.breaks
@@ -54,15 +60,55 @@ distsamp <- function(formula, data,
     nDP <- length(detParms)
     nP <- nAP + nDP
     cp <- matrix(NA, M, J)
+    switch(keyfun,
+           halfnorm = {
+               altdetParms <- paste("sigma", colnames(V), sep="")
+               if(is.null(starts)) {
+                   starts <- c(rep(0, nAP), log(max(db)), rep(0, nDP-1))
+                   names(starts) <- c(lamParms, detParms)
+               } else {
+                   if(is.null(names(starts))) names(starts) <-
+                       c(lamParms, detParms)
+               }
+           },
+           exp = {
+               altdetParms <- paste("rate", colnames(V), sep="")
+               if(is.null(starts)) {
+                   starts <- c(rep(0, nAP), 0, rep(0, nDP-1))
+                   names(starts) <- c(lamParms, detParms)
+               } else {
+                   if(is.null(names(starts))) names(starts) <-
+                       c(lamParms, detParms)
+               }
+           },
+           hazard = {
+               nDP <- length(detParms)
+               nP <- nAP + nDP + 1
+               altdetParms <- paste("shape", colnames(V), sep="")
+               if(is.null(starts)) {
+                   starts <- c(rep(0, nAP), log(median(db)),
+                               rep(0, nDP-1), 1)
+                   names(starts) <- c(lamParms, detParms, "scale")
+               } else {
+                   if(is.null(names(starts)))
+                       names(starts) <- c(lamParms, detParms, "scale")
+               }
+           },
+           uniform = {
+               detParms <- character(0)
+               altdetParms <- character(0)
+               nDP <- 0
+               if(is.null(starts)) {
+                   starts <- rep(0, length(lamParms))
+                   names(starts) <- lamParms
+               } else {
+                   if(is.null(names(starts))) names(starts) <- lamParms
+               }
+           })
+
+    if(engine=="R") {
     switch(keyfun,
     halfnorm = {
-        altdetParms <- paste("sigma", colnames(V), sep="")
-        if(is.null(starts)) {
-            starts <- c(rep(0, nAP), log(max(db)), rep(0, nDP-1))
-            names(starts) <- c(lamParms, detParms)
-            }
-        else
-            if(is.null(names(starts))) names(starts) <- c(lamParms, detParms)
         nll <- function(param) {
             sigma <- drop(exp(V %*% param[(nAP+1):nP] + V.offset))
             lambda <- drop(exp(X %*% param[1:nAP] + X.offset))
@@ -94,13 +140,6 @@ distsamp <- function(formula, data,
             -sum(ll)
             }},
     exp = {
-        altdetParms <- paste("rate", colnames(V), sep="")
-        if(is.null(starts)) {
-            starts <- c(rep(0, nAP), 0, rep(0, nDP-1))
-            names(starts) <- c(lamParms, detParms)
-            }
-        else
-            if(is.null(names(starts))) names(starts) <- c(lamParms, detParms)
         nll <- function(param) {
             rate <- drop(exp(V %*% param[(nAP+1):nP] + V.offset))
             lambda <- drop(exp(X %*% param[1:nAP] + X.offset))
@@ -137,16 +176,6 @@ distsamp <- function(formula, data,
             -sum(ll)
             }},
     hazard = {
-        nDP <- length(detParms)
-        nP <- nAP + nDP + 1
-        altdetParms <- paste("shape", colnames(V), sep="")
-        if(is.null(starts)) {
-            starts <- c(rep(0, nAP), log(median(db)), rep(0, nDP-1), 1)
-            names(starts) <- c(lamParms, detParms, "scale")
-            }
-        else
-            if(is.null(names(starts)))
-                names(starts) <- c(lamParms, detParms, "scale")
         nll <- function(param) {
             shape <- drop(exp(V %*% param[(nAP+1):(nP-1)] + V.offset))
             scale <- drop(exp(param[nP]))
@@ -185,15 +214,6 @@ distsamp <- function(formula, data,
             -sum(ll)
             }},
     uniform = {
-        detParms <- character(0)
-        altdetParms <- character(0)
-        nDP <- 0
-        if(is.null(starts)) {
-            starts <- rep(0, length(lamParms))
-            names(starts) <- lamParms
-            }
-        else
-            if(is.null(names(starts))) names(starts) <- lamParms
         nll <- function(param) {
             lambda <- drop(exp(X %*% param + X.offset))
             if(identical(output, "density"))
@@ -202,12 +222,33 @@ distsamp <- function(formula, data,
             -sum(ll)
             }
         })
+    } else if(engine=="C") {
+        nll <- function(param) {
+            beta.lam <- param[1:nAP]
+            if(identical(keyfun, "hazard")) {
+                beta.sig <- param[(nAP+1):(nP-1)]
+                scale <- exp(param[nP])
+            } else {
+                beta.sig <- param[(nAP+1):nP]
+                scale <- -99.0
+            }
+            lambda <- drop(exp(X %*% beta.lam + X.offset))
+            if(identical(output, "density"))
+                lambda <- lambda * A
+            sigma <- drop(exp(V %*% beta.sig + V.offset))
+            .Call("nll_distsamp",
+                  y, lambda, sigma, scale,
+                  a, u, w, db,
+                  keyfun, survey, rel.tol,
+                  PACKAGE="unmarked")
+        }
+    }
     fm <- optim(starts, nll, method=method, hessian=se, ...)
     opt <- fm
     ests <- fm$par
     if(se) {
         covMat <- tryCatch(solve(fm$hessian), error=function(x)
-        stop(simpleError("Hessian is singular. Try using fewer covariates or providing starting values.")))
+        simpleError("Hessian is singular. Try using fewer covariates or providing starting values."))
         if(class(covMat)[1] == "simpleError") {
             print(covMat$message)
             covMat <- matrix(NA, nP, nP)
